@@ -134,6 +134,13 @@ class Presentation:
 
         self.current_cap.set(cv2.CAP_PROP_POS_FRAMES, 0)
 
+    def cancel_reverse(self):
+        """Cancels any effet produced by a reversed slide."""
+        if self.reverse:
+            self.reverse = False
+            self.reversed_animation = -1
+            self.release_cap()
+
     def reverse_current_slide(self):
         """Reverses current slide."""
         self.reverse = True
@@ -142,9 +149,7 @@ class Presentation:
     def load_next_slide(self):
         """Loads next slide."""
         if self.reverse:
-            self.reverse = False
-            self.reversed_animation = -1
-            self.release_cap()
+            self.cancel_reverse()
             self.rewind_current_slide()
         elif self.current_slide.is_last():
             self.current_slide.terminated = True
@@ -156,6 +161,7 @@ class Presentation:
 
     def load_previous_slide(self):
         """Loads previous slide."""
+        self.cancel_reverse()
         self.current_slide_index = max(0, self.current_slide_index - 1)
         self.rewind_current_slide()
 
@@ -425,7 +431,7 @@ class Display:
         elif self.config.BACK.match(key):
             if self.current_presentation.current_slide_index == 0:
                 if self.current_presentation_index == 0:
-                    self.current_presentation.rewind_current_slide()
+                    self.current_presentation.load_previous_slide()
                 else:
                     self.current_presentation_index -= 1
                     self.current_presentation.load_last_slide()
@@ -437,6 +443,7 @@ class Display:
             self.current_presentation.reverse_current_slide()
             self.state = State.PLAYING
         elif self.config.REWIND.match(key):
+            self.current_presentation.cancel_reverse()
             self.current_presentation.rewind_current_slide()
             self.state = State.PLAYING
 
@@ -501,7 +508,7 @@ def _list_scenes(folder) -> List[str]:
                 filepath = os.path.join(folder, file)
                 _ = PresentationConfig.parse_file(filepath)
                 scenes.append(os.path.basename(file)[:-5])
-            except Exception as e:  # Could not parse this file as a proper presentation config
+            except Exception:  # Could not parse this file as a proper presentation config
                 pass
 
     return scenes
@@ -529,7 +536,7 @@ def _list_scenes(folder) -> List[str]:
     "--resolution",
     type=(int, int),
     default=(1920, 1080),
-    help="Window resolution used if fullscreen is not set. You may manually resize the window afterward.",
+    help="Window resolution WIDTH HEIGHT used if fullscreen is not set. You may manually resize the window afterward.",
     show_default=True,
 )
 @click.option(
@@ -558,7 +565,15 @@ def present(
     interpolation_flag,
     record_to,
 ):
-    """Present the different scenes."""
+    """
+    Present SCENE(s), one at a time, in order.
+
+    Each SCENE parameter must be the name of a Manim scene, with existing SCENE.json config file.
+
+    You can present the same SCENE multiple times by repeating the parameter.
+
+    Use `manim-slide list-scenes` to list all available scenes in a given folder.
+    """
 
     if len(scenes) == 0:
         scene_choices = _list_scenes(folder)
